#!/usr/bin/perl

# $Id:  $
# Copyright (c) 2013 Network Appliance, Inc.
# All rights reserved.

package Password;

use strict;
use Term::ReadKey;
use Passwd::Unix;

=head1 NAME

Password - Password capture and processing.

=head1 DESCRIPTION

Password - Password capture and processing.


=head1 SUBROUTINES

=over 4


=item B<testPasswordStrength>

    Function   : Test given password for minimal complexity.
    Parameters : Password to test.
    Returns    : 0 for good, non-zero for fail.

=cut
sub testPasswordStrength($) {
    my $rc = 0;
    my $password = $_[0]; # arg1
    my $min_len = 8;
    
    my $pw_len = length($password);
    if ($pw_len < $min_len) {
        print "\nPlease use a longer password.\n";
        $rc = 1;
    }
    
    return $rc;
}

=item B<capturePassword>

    Function   : Prompt for and invisibly capture the user's password input.
    Returns    : Captured password or empty string for failure.

=cut
sub capturePassword() {
    my ($result, $password, $verification, $attempts);
    $result = "";
    $attempts = 3;
    
    while ($result eq "" && $attempts ge 0) {
        print "\nEnter new password: ";
        ReadMode 'noecho';
        $password = ReadLine 0;
        chomp $password;
        # Must have some input
        if ($password eq "") {
            print "\nNo password entered.\n";
            $attempts -= 1;
            next;
        }
        print "\nRetype new password: ";
        $verification = ReadLine 0;
        chomp $verification;
        print "\n"; 
        # Verify that both entries match
        if ($password eq $verification) {
            # match
            if (testPasswordStrength($password) eq 0) {
                # Looks good
                $result = $password;
            } else {
                $attempts -= 1;
            }
        } else {
            # mismatch
            print "\nPassword input mismatch\n";
            $attempts -= 1;
            next;
        }
    }
    
    ReadMode 'normal';

    return $result;
}

=item B<askPassword>

    Function   : Prompt for and invisibly capture the user's password input.
    Returns    : Captured password or empty string for failure.

=cut
sub askPassword() {
    my ($result, $password, $verification, $attempts);
    $result = "";
    $attempts = 3;
    
    while ($result eq "" && $attempts ge 0) {
        ReadMode 'noecho';
        $password = ReadLine 0;
        chomp $password;
        # Must have some input
        if ($password eq "") {
            print "\nNo password entered.\n";
            $attempts -= 1;
            next;
        }
        $result = $password;
    }
    
    ReadMode 'normal';

    return $result;
}


=back

=cut

1; # so the require or use succeeds
