#!/bin/bash

# $Id: $
# Copyright (c) 2013 NetApp, Inc.
# All rights reserved.

# Checks/enables/disables SSH access.
#
# This script must be run as root. In order to change the ssh state,
# it must be run via the vm console.
#
# Enforcement is as follows:
#     ownership:   root:root
#     permissions: -r-x------
#     The maintenance user is given sudo access to this script.

set -e

# Note that /home/maint/scripts/commonfunctions.sh
# needs to be owned by root and writable only by root for this to be secure
. /home/maint/scripts/commonfunctions.sh

function debug_enabled_check() {
    grep -qx "\-A INPUT \-p tcp \-\-dport 8000 \-j ACCEPT" /etc/iptables/rules.v4
    local rc=$?
    if [ $rc -eq 0 ]; then
        return 1
    else
        return 0
    fi
}

function debug_enable() {
    echo
    echo -n "Would you like to enable debug access? (y/n) "
    read enableDebug
    if [[ $enableDebug = [yY] ]] ; then
        echo
        echo -n "Enabling debug access... "
        sed -i 's/#-A INPUT -p tcp --dport 8000 -j ACCEPT/-A INPUT -p tcp --dport 8000 -j ACCEPT/' /etc/iptables/rules.v4
        service iptables-persistent reload
    fi
}

function debug_disable() {
    echo
    echo -n "Would you like to disable debug access? (y/n) "
    read disableDebug
    if [[ $disableDebug = [yY] ]] ; then
        echo
        echo -n "Disabling debug acess... "
        sed -i 's/-A INPUT -p tcp --dport 8000 -j ACCEPT/#-A INPUT -p tcp --dport 8000 -j ACCEPT/' /etc/iptables/rules.v4
        service iptables-persistent reload
    fi
}


function main() {
    local rc=0

    debug_enabled_check  || {
        rc=1
    }

    if [[ $# -eq 1 ]] ; then
        onVmConsole || {
            echo
            echo "Debug access can be toggled by accessing this prompt through the"
            echo "virtual machine console."
            exit $rc
        }
        
        case "$1" in
            "enable")
                    debug_enable
                    ;;
            "disable")
                    debug_disable
                    ;;
        esac
        rc=$(debug_enabled_check)
    fi

    exit $rc
}

main "$@"
