#!/bin/bash

# $Id: $
# Copyright (c) 2013 NetApp, Inc.
# All rights reserved.

# Enables/disables remote diagnostic access.
#
# This script must be run as root. In order to change the diag user,
# it must be run via the vm console.
#
# Enforcement is as follows:
#     ownership:   root:root
#     permissions: -r-x------
#     The maintenance user is given sudo access to this script.

set -e

# Note that /home/maint/scripts/commonfunctions.sh
# needs to be owned by root and writable only by root for this to be secure
. /home/maint/scripts/commonfunctions.sh

# Returns 0 if diag is unlocked and not expired (else returns 1).
function diag_unlocked_check() {
    userLocked diag && return 1 || userExpired diag && return 1 ||
        return 0
}

function diag_unlock() {
    echo
    echo -n "Would you like to enable remote diagnostic access? (y/n) "
    read enableDiag
    if [[ $enableDiag = [yY] ]] ; then
        echo
        echo "Set the password for diagnostic access at the prompts below."
        echo
        /usr/bin/chattr -i /etc/passwd /etc/shadow
        passwd diag || {
            /usr/bin/chattr +i /etc/passwd /etc/shadow
            echo
            echo "Error setting password. Not enabling diagnostic access."
            exit 1
        }
            /usr/bin/chattr +i /etc/passwd /etc/shadow
        logger -p "auth.info" "diag user enabled"

        diag_set_expiration
    fi
}

function diag_set_expiration() {
    expirationDate=`date --date="tomorrow" +%Y-%m-%d`
    echo
    /usr/bin/chattr -i /etc/passwd /etc/shadow
    usermod --expiredate "$expirationDate" diag > /dev/null 2>&1 && {
                echo "Remote diagnostic access will be disabled after midnight UTC tomorrow ($expirationDate) or after the first use."
            } || {
                echo "Error setting expiration date."
            }
    /usr/bin/chattr +i /etc/passwd /etc/shadow
}

function diag_lock() {
    echo
    echo -n "Would you like to disable remote diagnostic access? (y/n) "
    read disableDiag
    if [[ $disableDiag != [nN] ]] ; then
        echo
        echo -n "Disabling remote diagnostic access... "
        /usr/bin/chattr -i /etc/passwd /etc/shadow
        usermod --lock --expiredate -1 diag > /dev/null 2>&1 && {
            logger -p "auth.info" "diag user disabled"
            echo "Done."
        } || {
            logger -p "auth.info" "failure disabling diag user"
            echo "Failed."
        }
        /usr/bin/chattr +i /etc/passwd /etc/shadow
    fi
}

diag_unlocked_check && {
    echo "Remote diagnostic access is enabled."
} || {
    echo "Remote diagnostic access is disabled."
}

# This point forward requires that the user is in the vCenter console
onVmConsole || {
    echo
    echo "Remote diagnostic access can be toggled by accessing this prompt through the"
    echo "virtual machine console."
    exit 0
}

diag_unlocked_check && {
    diag_lock
} || {
    diag_unlock
}
