#!/bin/bash

# $Id$
# Copyright (c) 2013 Network Appliance, Inc.
# All rights reserved.

. /home/maint/scripts/commonfunctions.sh

data_disk=/opt

# This script expands size of data disk on appliance.
# Data disk is "hard disk 3" as shown in vsphere client.

function extend_xfs_file_system () {
	# Remount data disk
	mount -t xfs  $1 ${data_disk}

	# grow xfs filesystem on the data disk
	xfs_growfs ${data_disk} >/dev/null
}

# Extend ext3 file system on the data disk.
function extend_ext3_file_system () {
	# Check the sanity of ext3 file system.
	e2fsck -p -f $1 >&/dev/null
	if [ $? -ne 0 ] ;then
		echo "ext3 file system sanity check failed before disk expand"
		echo "exiting ...."
		exit 100
	fi

	# Resize ext3 file system.
	resize2fs -p $1 >&/dev/null
	if [ $? -ne 0 ] ; then
		echo "resizing ext3 file system failed."
		echo "exiting ..."
	fi

	# Again check the sanity of ext3 file system
	e2fsck -p -f $1 >&/dev/null
	if [ $? -ne 0 ] ;then
		echo "ext3 file system sanity check failed after disk expand"
		echo "exiting ...."
		exit 100
	fi

	# mount data disk
	mount ${data_disk}
}

# Extend data disk.
function extend_data_disk () {
        # Get old disk size
        oldSize=`df -m | grep ${data_disk}$ | awk '{print $1}' | tr -d '\n'`

        # Get UUID for data disk and get physical device for data disk.
        data_mapper_device=`cat /etc/fstab | grep "${data_disk}"  | cut -d' ' -f1`
        data_device=`pvs | grep "/dev/sd" | awk '{print $1}' | tr -d '\n'`

        # Stop all the services which may use data disk
        serverStartStop all stop
        
        echo
        if [[ ${servicestop} -ne 1 ]]; then
                echo "The applications could not be stopped."
                echo" Exiting the process of increasing data disk size..."
                exit 1
        fi
        
        # umount data disk
        umount ${data_disk}

        # Re-read the partition table to get new sizes.
        blockdev -q --rereadpt $data_device

        # Resize the data disk
        pvresize $data_device >/dev/null

        # Extend lv.
        lvextend -l +100%FREE $data_mapper_device >&/dev/null

        # Find out file system on the data disk.
        filesystem=`cat /etc/fstab | grep data | cut -d' ' -f3`
        if [ $filesystem == "xfs" ] ; then
            # data disk have xfs file system.
            extend_xfs_file_system $data_mapper_device
        else
            # data disk have ext3 file system.
            extend_ext3_file_system $data_mapper_device
        fi


        # Get the new size and print a msg for user
        newSize=`df -m | grep ${data_disk}$ | awk '{print $1}' | tr -d '\n'`

        # Start all the stopped services
        serverStartStop all start

        if [ $newSize -gt $oldSize ] ; then
                echo "The size of data disk is increased from $oldSize MB to $newSize MB."
                return 0
        else
                echo "The data disk size could not be increased."
                echo "Ensure that you increased the data disk size from the vSphere Client"
                echo "before running this script."
                echo "Data disk is \"Hard Disk 3\" as shown in the \"Edit Settings\""
                echo "section of your VM in the vSphere Client."
                return 1
        fi


}


# check to see if data disk exist
df -kh ${data_disk} >&/dev/null
if [ $? -eq 0 ] ; then
	# Go ahead
	echo
	echo "Before continuing with this option, ensure that you have increased the data"
	echo "disk size from \"Edit Settings\" section of your VM in the vSphere Client."
	echo "If you have not increased the data disk size, you can do so now and then"
	echo "type \"yes\" in the below prompt."
	echo "Data disk is \"Hard Disk 3\" as shown in \"Edit Settings\""
	echo "section of your VM in the vSphere Client."
	echo
	echo
	echo
	echo "Increasing data disk size will temporarily stop the applications."
	echo "After increasing data disk size, applications will restart."
	echo


	read -r -p "Do you wish to continue? (y/n):" answer
	if [ "$answer" != "y" ]; then
		exit 1
	fi

	extend_data_disk
else
	# Error out
	echo "mount point ${data_disk} does not exist"
	exit 1
fi
