#!/bin/bash

# $Id$
# Copyright (c) 2013 Network Appliance, Inc.
# All rights reserved.

. /home/maint/scripts/commonfunctions.sh

# This script expands size of swap disk on appliance.
# Swap disk is "hard disk 2" as shown in vsphere client.

function extend_swap_disk() {

	# Get old size of swap space
	oldSize=` free -m | grep Swap | awk '{print $2}' | tr -d '\n'`

	# Get swap label and find out swap device.
	swap_label=`grep swap /etc/fstab | awk '{print $1}' | cut -d'"' -f2`
	swap_device=`blkid | grep $swap_label | cut -d':' -f1 |  tr -d [1-9]`

	# Stop all the services which may use swap disk
    serverStartStop all stop
    
    echo
    if [[ ${servicestop} -ne 1 ]]; then
            echo "The applications could not be stopped. Exiting the process of increasing swap disk size..."
            exit 1
    fi

	# Switch off usage of swap disk
	swapoff -a
	if [ $? -ne 0 ] ; then
		echo "Could not do swapoff successfully, Most probably swap space is in use"
		echo "and can't be freed. Exiting ...."
		exit 1
	fi

	# Re-read the partiton table to get new size.
	blockdev --rereadpt $swap_device

	# Repartition the swap disk to new sizes.
	parted $swap_device resize 1 0% 100% >&/dev/null

	# make swap file system on whole disk.
	mkswap $swap_device 2&>/dev/null

	# Switch on swap
	swapon -a

	# Get the new size.
	newSize=` free -m | grep Swap | awk '{print $2}' | tr -d '\n'`

	# Start all the stoped services.
	serverStartStop all start

    if [ $newSize -gt $oldSize ] ; then
    echo "Increased swap disk size from $oldSize MB to $newSize MB"
            return 0
    else
            echo "The swap disk size could not be increased."
    echo "Ensure that you increased the swap disk size from the vSphere Client before"
    echo "running this script."
    echo "Swap disk is \"Hard Disk 2\" as shown in the \"Edit Settings\""
    echo "section of your VM in the vSphere Client."
    return 1
    fi
}

# Check if the swap disk is available
swapSize=`free | grep Swap | awk '{print $2}'`
if [ $swapSize > 0 ] ; then
	# Go ahead with disk size extend
        echo
        echo "Before continuing with this option, ensure that you have increased"
        echo "the swap disk size from \"Edit Settings\" section of your VM in the"
        echo "vSphere Client."
        echo "If you have not increased the swap disk size, you can do so now and then"
        echo "type \"yes\" in the below prompt."
        echo "Swap disk is \"Hard Disk 2\" as shown in \"Edit Settings\""
        echo "section of your VM in the vSphere Client."
        echo
        echo
        echo
        echo "Increasing swap disk size will temporarily stop the applications."
        echo "After increasing swap disk size, applications will restart."
        echo


	read -r -p "Do you wish to continue? (y/n):" answer
	if [ "$answer" != "y" ]; then
		exit 1
	fi

	extend_swap_disk
else
	echo "Can not increase swap disk size"
	echo "Either swap disk is not present or the usage of swap is not switched on"
	exit 1
fi
